/**
 * Base element in Open Document Format
 * @since 0.1.0
 * @private
 */
export declare class OdfElement {
    private children;
    /**
     * Constructor.
     * @since 0.1.0
     */
    constructor();
    /**
     * Returns all child elements.
     *
     * @returns {OdfElement[]} A copy of the list of child elements
     * @since 0.2.0
     */
    getAll(): OdfElement[];
    /**
     * Appends the element as a child element to this element.
     *
     * @param {OdfElement} element The element to append
     * @since 0.1.0
     */
    protected append(element: OdfElement): void;
    /**
     * Inserts the element at the specified position in the list of child elements.
     *
     * @param {number} position The index at which to insert the element (starting from 0).
     * If greater than the number child elements, the element will appended at the end of the list.
     * If negative, the element will be inserted as first element.
     * @param {OdfElement} element The element to insert
     * @since 0.2.0
     */
    protected insert(position: number, element: OdfElement): void;
    /**
     * Returns the element at the specified position.
     *
     * @param {number} position The index of the requested the element (starting from 0).
     * @returns {OdfElement | undefined} The element at the specified position
     * or undefined if there is no element at the specified position
     * @since 0.2.0
     */
    protected get(position: number): OdfElement | undefined;
    /**
     * Removes the child element from the specified position.
     *
     * @param {number} position The index of the element to remove (starting from 0).
     * @returns {OdfElement | undefined} The removed child element
     * or undefined if there is no element at the specified position
     * @since 0.2.0
     */
    protected removeAt(position: number): OdfElement | undefined;
    /**
     * Returns whether the element has any child elements.
     *
     * @returns {boolean} TRUE if the there is any child element, FALSE otherwise
     * @since 0.2.0
     */
    protected hasChildren(): boolean;
}
