/**
 * This class represents a Color.
 *
 * @since 0.4.0
 */
export declare class Color {
    private red;
    private green;
    private blue;
    /**
     * The `Color.fromHex()` method parses a string argument and returns a color.
     * The string is expected to be in `#rrggbb` or `rrggbb` format.
     *
     * @param {string} value The value you want to parse
     * @returns {Color | never} A color parsed from the given value
     * @throws {Error} If the value cannot be converted to a color
     * @since 0.4.0
     */
    static fromHex(value: string): Color | never;
    /**
     * The `Color.fromRgb()` method returns a color with the channel arguments.
     *
     * @param {number} red The red channel of the color with a range of 0...255
     * @param {number} green The green channel of the color with a range of 0...255
     * @param {number} blue The blue channel of the color with a range of 0...255
     * @returns {Color | never} A color parsed from the given value
     * @throws {Error} If any channel is outside the allowable range
     * @since 0.4.0
     */
    static fromRgb(red: number, green: number, blue: number): Color | never;
    /**
     * The `Color.checkRange()` method determines whether the passed value is inside the allowable range.
     *
     * @param {number} value The value to be tested
     * @returns {boolean} A `Boolean` indicating whether or not the given value is inside the allowable range
     * @since 0.4.0
     * @private
     */
    private static checkRange;
    /**
     * The `Color.numberToHex()` method returns a string representing the number argument as a two-character hex string.
     *
     * @param {number} value The number value to convert
     * @returns {string} A string representing the given number value
     * @since 0.4.0
     * @private
     */
    private static numberToHex;
    /**
     * Creates a new color with the specified channel values.
     *
     * @param {number} red The red channel of the color
     * @param {number} green The green channel of the color
     * @param {number} blue The blue channel of the color
     * @since 0.4.0
     * @private
     */
    private constructor();
    /**
     * The toHex() method returns a string representing the color as hex string.
     *
     * @returns {string} A hex string representing the color
     * @since 0.4.0
     */
    toHex(): string;
}
