"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ParagraphProperties = void 0;
const util_1 = require("../util");
const HorizontalAlignment_1 = require("./HorizontalAlignment");
const HorizontalAlignmentLastLine_1 = require("./HorizontalAlignmentLastLine");
const PageBreak_1 = require("./PageBreak");
const TabStopType_1 = require("./TabStopType");
const TabStop_1 = require("./TabStop");
const VerticalAlignment_1 = require("./VerticalAlignment");
class ParagraphProperties {
    constructor() {
        this.tabStops = [];
        this.horizontalAlignment = HorizontalAlignment_1.HorizontalAlignment.Default;
        this.horizontalAlignmentLastLine = HorizontalAlignmentLastLine_1.HorizontalAlignmentLastLine.Default;
        this.marginBottom = 0;
        this.marginLeft = 0;
        this.marginRight = 0;
        this.marginTop = 0;
        this.paddingBottom = 0;
        this.paddingLeft = 0;
        this.paddingRight = 0;
        this.paddingTop = 0;
        this.pageBreak = PageBreak_1.PageBreak.None;
        this.shouldKeepTogether = false;
        this.shouldKeepWithNext = false;
        this.textIndent = 0;
        this.verticalAlignment = VerticalAlignment_1.VerticalAlignment.Default;
    }
    /** @inheritdoc */
    setBackgroundColor(color) {
        this.backgroundColor = color;
    }
    /** @inheritdoc */
    getBackgroundColor() {
        return this.backgroundColor;
    }
    /** @inheritdoc */
    setBorder(width, style, color) {
        this.setBorderBottom(width, style, color);
        this.setBorderLeft(width, style, color);
        this.setBorderRight(width, style, color);
        this.setBorderTop(width, style, color);
    }
    /** @inheritdoc */
    removeBorder() {
        this.removeBorderBottom();
        this.removeBorderLeft();
        this.removeBorderRight();
        this.removeBorderTop();
    }
    /** @inheritdoc */
    setBorderBottom(width, style, color) {
        if ((0, util_1.isNonNegativeNumber)(width)) {
            this.borderBottom = { width, style, color };
        }
    }
    /** @inheritdoc */
    getBorderBottom() {
        return this.borderBottom;
    }
    /** @inheritdoc */
    removeBorderBottom() {
        this.borderBottom = undefined;
    }
    /** @inheritdoc */
    setBorderLeft(width, style, color) {
        if ((0, util_1.isNonNegativeNumber)(width)) {
            this.borderLeft = { width, style, color };
        }
    }
    /** @inheritdoc */
    getBorderLeft() {
        return this.borderLeft;
    }
    /** @inheritdoc */
    removeBorderLeft() {
        this.borderLeft = undefined;
    }
    /** @inheritdoc */
    setBorderRight(width, style, color) {
        if ((0, util_1.isNonNegativeNumber)(width)) {
            this.borderRight = { width, style, color };
        }
    }
    /** @inheritdoc */
    getBorderRight() {
        return this.borderRight;
    }
    /** @inheritdoc */
    removeBorderRight() {
        this.borderRight = undefined;
    }
    /** @inheritdoc */
    setBorderTop(width, style, color) {
        if ((0, util_1.isNonNegativeNumber)(width)) {
            this.borderTop = { width, style, color };
        }
    }
    /** @inheritdoc */
    getBorderTop() {
        return this.borderTop;
    }
    /** @inheritdoc */
    removeBorderTop() {
        this.borderTop = undefined;
    }
    /** @inheritdoc */
    setHorizontalAlignment(horizontalAlignment) {
        this.horizontalAlignment = horizontalAlignment;
    }
    /** @inheritdoc */
    getHorizontalAlignment() {
        return this.horizontalAlignment;
    }
    /** @inheritdoc */
    setHorizontalAlignmentLastLine(horizontalAlignment) {
        this.horizontalAlignmentLastLine = horizontalAlignment;
    }
    /** @inheritdoc */
    getHorizontalAlignmentLastLine() {
        return this.horizontalAlignmentLastLine;
    }
    /** @inheritdoc */
    setKeepTogether(keepTogether = true) {
        this.shouldKeepTogether = keepTogether;
    }
    /** @inheritdoc */
    getKeepTogether() {
        return this.shouldKeepTogether;
    }
    /** @inheritdoc */
    setKeepWithNext(keepWithNext = true) {
        this.shouldKeepWithNext = keepWithNext;
    }
    /** @inheritdoc */
    getKeepWithNext() {
        return this.shouldKeepWithNext;
    }
    /** @inheritdoc */
    setLineHeight(lineHeight) {
        if ((0, util_1.isNonNegativeNumber)(lineHeight) ||
            (0, util_1.isPercent)(lineHeight) ||
            lineHeight === undefined) {
            this.lineHeight = lineHeight;
        }
    }
    /** @inheritdoc */
    getLineHeight() {
        return this.lineHeight;
    }
    /** @inheritdoc */
    setLineHeightAtLeast(minimumLineHeight) {
        if ((0, util_1.isNonNegativeNumber)(minimumLineHeight) ||
            minimumLineHeight === undefined) {
            this.minimumLineHeight = minimumLineHeight;
        }
    }
    /** @inheritdoc */
    getLineHeightAtLeast() {
        return this.minimumLineHeight;
    }
    /** @inheritdoc */
    setLineSpacing(lineSpacing) {
        this.lineSpacing = lineSpacing;
    }
    /** @inheritdoc */
    getLineSpacing() {
        return this.lineSpacing;
    }
    /** @inheritdoc */
    setMarginBottom(margin) {
        if ((0, util_1.isNonNegativeNumber)(margin)) {
            this.marginBottom = margin;
        }
    }
    /** @inheritdoc */
    getMarginBottom() {
        return this.marginBottom;
    }
    /** @inheritdoc */
    setMarginLeft(margin) {
        this.marginLeft = margin;
    }
    /** @inheritdoc */
    getMarginLeft() {
        return this.marginLeft;
    }
    /** @inheritdoc */
    setMarginRight(margin) {
        this.marginRight = margin;
    }
    /** @inheritdoc */
    getMarginRight() {
        return this.marginRight;
    }
    /** @inheritdoc */
    setMarginTop(margin) {
        if ((0, util_1.isNonNegativeNumber)(margin)) {
            this.marginTop = margin;
        }
    }
    /** @inheritdoc */
    getMarginTop() {
        return this.marginTop;
    }
    /** @inheritdoc */
    setMargin(marginLeft, marginRight, marginTop, marginBottom) {
        this.setMarginLeft(marginLeft);
        this.setMarginRight(marginRight);
        this.setMarginTop(marginTop);
        this.setMarginBottom(marginBottom);
    }
    /** @inheritdoc */
    setOrphans(orphans) {
        if ((0, util_1.isNonNegativeNumber)(orphans)) {
            this.orphans = Math.trunc(orphans);
            return;
        }
        if (orphans === undefined) {
            this.orphans = orphans;
        }
    }
    /** @inheritdoc */
    getOrphans() {
        return this.orphans;
    }
    /** @inheritdoc */
    setPaddingBottom(padding) {
        if ((0, util_1.isNonNegativeNumber)(padding)) {
            this.paddingBottom = padding;
        }
    }
    /** @inheritdoc */
    getPaddingBottom() {
        return this.paddingBottom;
    }
    /** @inheritdoc */
    setPaddingLeft(padding) {
        if ((0, util_1.isNonNegativeNumber)(padding)) {
            this.paddingLeft = padding;
        }
    }
    /** @inheritdoc */
    getPaddingLeft() {
        return this.paddingLeft;
    }
    /** @inheritdoc */
    setPaddingRight(padding) {
        if ((0, util_1.isNonNegativeNumber)(padding)) {
            this.paddingRight = padding;
        }
    }
    /** @inheritdoc */
    getPaddingRight() {
        return this.paddingRight;
    }
    /** @inheritdoc */
    setPaddingTop(padding) {
        if ((0, util_1.isNonNegativeNumber)(padding)) {
            this.paddingTop = padding;
        }
    }
    /** @inheritdoc */
    getPaddingTop() {
        return this.paddingTop;
    }
    /** @inheritdoc */
    setPadding(paddingLeft, paddingRight, paddingTop, paddingBottom) {
        this.setPaddingLeft(paddingLeft);
        this.setPaddingRight(paddingRight);
        this.setPaddingTop(paddingTop);
        this.setPaddingBottom(paddingBottom);
    }
    /** @inheritdoc */
    setPageBreak(pageBreak) {
        this.pageBreak = pageBreak;
    }
    /** @inheritdoc */
    getPageBreak() {
        return this.pageBreak;
    }
    /** @inheritdoc */
    setTextIndent(textIndent) {
        this.textIndent = textIndent;
    }
    /** @inheritdoc */
    getTextIndent() {
        return this.textIndent;
    }
    /** @inheritdoc */
    setVerticalAlignment(verticalAlignment) {
        this.verticalAlignment = verticalAlignment;
    }
    /** @inheritdoc */
    getVerticalAlignment() {
        return this.verticalAlignment;
    }
    /** @inheritdoc */
    setWidows(widows) {
        if ((0, util_1.isNonNegativeNumber)(widows)) {
            this.widows = Math.trunc(widows);
            return;
        }
        if (widows === undefined) {
            this.widows = widows;
        }
    }
    /** @inheritdoc */
    getWidows() {
        return this.widows;
    }
    addTabStop(arg1, type = TabStopType_1.TabStopType.Left) {
        const newTabStop = typeof arg1 === 'object' ? arg1 : new TabStop_1.TabStop(arg1, type);
        const existsTabStop = this.tabStops.some((value) => {
            return newTabStop.getPosition() === value.getPosition();
        });
        if (existsTabStop === true) {
            return undefined;
        }
        this.tabStops.push(newTabStop);
        this.sortTabStops();
        return newTabStop;
    }
    /** @inheritdoc */
    getTabStops() {
        return Array.from(this.tabStops);
    }
    /** @inheritdoc */
    clearTabStops() {
        this.tabStops = [];
    }
    /**
     * Sorts the tab stops by their position ascending.
     */
    sortTabStops() {
        this.tabStops.sort((a, b) => {
            return a.getPosition() - b.getPosition();
        });
    }
}
exports.ParagraphProperties = ParagraphProperties;
