import { Paragraph } from './Paragraph';
/**
 * This class represents a heading in a document.
 *
 * It is used to structure a document into multiple sections.
 * A chapter or section begins with a heading and extends to the next heading at the same or higher level.
 *
 * @example
 * document.getBody().addHeading('First Headline', 1);
 *
 * @example
 * document.getBody().addHeading()
 *   .setText('Second Headline')
 *   .setLevel(2);
 *
 * @extends {Paragraph}
 * @since 0.1.0
 */
export declare class Heading extends Paragraph {
    private level;
    static DEFAULT_LEVEL: number;
    /**
     * Creates a `Heading` instance that represents a heading in a document.
     *
     * @example
     * new Heading('First Headline', 1);
     * new Heading('First Headline');
     * new Heading();
     *
     * @param {string} [text=''] The text content of the heading; defaults to an empty string if omitted
     * @param {number} [level=1] The level of the heading, starting with `1`; defaults to `1` if omitted
     * @since 0.1.0
     */
    constructor(text?: string, level?: number);
    /**
     * The `setLevel()` method sets the level of the heading, starting with `1`.
     * If an illegal value is provided, then the heading is assumed to be at level `1`.
     *
     * @param {number} level The level of the heading, starting with `1`
     * @returns {Heading} The `Heading` object
     * @since 0.1.0
     */
    setLevel(level: number): Heading;
    /**
     * The `getLevel()` method returns the level of the heading.
     *
     * @returns {number} The level of the heading
     * @since 0.1.0
     */
    getLevel(): number;
}
