import { TextDocument } from '../api/office';
/**
 * Transforms a {@link TextDocument} object into ODF conform XML
 *
 * @since 0.7.0
 */
export declare class TextDocumentWriter {
    private fontFaceDeclarationsWriter;
    private metaWriter;
    private stylesWriter;
    constructor();
    /**
     * Transforms the given {@link TextDocument} into Open Document Format.
     *
     * @param {TextDocument} textDocument The text document to serialize
     * @returns {Document} The XML document
     * @since 0.7.0
     */
    write(textDocument: TextDocument): Document;
    /**
     * Declares the used XML namespaces.
     *
     * @param {Element} root The root element of the document which will be used as parent
     * @private
     */
    private setXmlNamespaces;
    /**
     * Sets the mime type and the version attributes.
     *
     * @param {TextDocument} textDocument The text document to serialize
     * @param {Element} root The root element of the document which will be used as parent
     * @private
     */
    private setOfficeAttributes;
    /**
     * Adds the meta data to the document.
     *
     * @param {TextDocument} textDocument The text document to serialize
     * @param {Document} document The parent node in the DOM
     * @param {Element} root The root element of the document which will be used as parent
     * @private
     */
    private writeMeta;
    /**
     * Adds the font face declarations to the document.
     *
     * @param {TextDocument} textDocument The text document to serialize
     * @param {Document} document The parent node in the DOM
     * @param {Element} root The root element of the document which will be used as parent
     * @private
     */
    private writeFontFaceDeclarations;
    /**
     * Adds the styles to the document.
     *
     * @param {TextDocument} textDocument The text document to serialize
     * @param {AutomaticStyles} automaticStyles The automatic styles for the document
     * @param {Document} document The parent node in the DOM
     * @param {Element} root The root element of the document which will be used as parent
     * @private
     */
    private writeStyles;
    /**
     * Adds the documents body to the document.
     *
     * @param {TextDocument} textDocument The text document to serialize
     * @param {AutomaticStyles} automaticStyles The automatic styles for the document
     * @param {Document} document The parent node in the DOM
     * @param {Element} root The root element of the document which will be used as parent
     * @private
     */
    private writeBody;
}
